@@ -5,12 +5,13 @@ use strict;
 use utf8;
 use base 'POD2::Base';
 
-our $VERSION = '5.12.3.01_3';
+our $VERSION = '5.12.3.02';
 
 my $pods = {
     perlintro   => '5.12.3',
-    # perl       => '5.12.3',
-    # perlbook   => '5.12.3',
+    perl        => '5.12.3',
+    perlbook    => '5.12.3',
+    perlunitut  => '5.12.3',
     # perlcheat  => '5.12.3',
     # perldata   => '5.12.3',
     # perlfunc   => '5.12.3',
@@ -181,10 +182,10 @@ Para este proyecto hemos tomado las siguientes decisiones:
 =item * No utilizar caracteres acentuados en los nombres de variables y
 funciones de los ejemplos de cdigo
 
-Es perfectamente posible utilizarlos, (solo hay que codificar el programa
+Es perfectamente posible utilizarlos (solo hay que codificar el programa
 como UTF-8 y agregar "use utf8;" al principio), pero teniendo en mente a
 ese programador ms impulsivo, que valora su tiempo y no quiere perderse en
-reflexiones ni verse encorsetado por las normas del lenguaje, creemos que
+reflexiones ni verse encorsetado por las normas de la lengua, creemos que
 as resultar ms fcil probar el cdigo de los ejemplos.
 
 Por otra parte, en aquellos sistemas que cuenten con un sistema antiguo de
@@ -215,10 +216,6 @@ Espaa y Latinoamrica.
 
 =back
 
-=head1 REFERENCIAS
-
-Proyecto OmegaT: L<http://omegat.org/>
-
 
 =head1 VEA TAMBIN
 
@@ -266,9 +263,27 @@ L<http://search.cpan.org/dist/POD2-ES/>
 
 =head1 AGRADECIMIENTOS
 
-Los autores desean expresar su agradecimiento al equipo de desarrollo
+Los autores desean expresar su gratitud al equipo de desarrollo
 de OmegaT, la herramienta utilizada para la traduccin.
 
+
+=head1 REFERENCIAS
+
+Proyecto OmegaT: L<http://omegat.org/>
+
+
+=head1 DONATIVOS
+
+Por el elevado volumen de trabajo que representa y su larga duracin,
+el proyecto de traduccin de la documentacin de Perl requiere un 
+esfuerzo sostenido que slo est al alcance de los espritus ms 
+slidos y altruistas.
+Los autores no exigen--pero tampoco rechazarn--compensaciones en 
+forma de dinero, libros, quesos y productos derivados del cerdo (o chancho),
+o incluso viajes a la Polinesia, destinadas a reducir la fatiga del
+equipo y a mantener alta la moral. Todo ser bienvenido.
+
+
 =head1 LICENCIA Y COPYRIGHT
 
 Copyright 2011 Equipo de Perl en Espaol.
